@@ -1,4 +1,5 @@
 from mc.net.minecraft.character.ZombieModel import ZombieModel
+from mc.net.minecraft.renderer.Textures import Textures
 from mc.net.minecraft.Entity import Entity
 from mc.CompatibilityShims import getNs
 from pyglet import gl
@@ -7,11 +8,10 @@ import random
 import math
 
 class Zombie(Entity):
-    zombieModel = ZombieModel()
+    __zombieModel = ZombieModel()
 
-    def __init__(self, level, textures, x, y, z):
+    def __init__(self, level, x, y, z):
         super().__init__(level)
-        self.textures = textures
         self.rotA = (random.random() + 1.0) * 0.01
         self.setPos(x, y, z)
         self.timeOffs = random.random() * 1239813.0
@@ -49,13 +49,14 @@ class Zombie(Entity):
             self.xd *= 0.7
             self.zd *= 0.7
 
-    def render(self, a):
+    def render(self, textures, a):
         gl.glEnable(gl.GL_TEXTURE_2D)
-        gl.glBindTexture(gl.GL_TEXTURE_2D, self.textures.loadTexture('char.png', gl.GL_NEAREST))
+        gl.glBindTexture(gl.GL_TEXTURE_2D, textures.loadTexture('char.png', gl.GL_NEAREST))
 
         gl.glPushMatrix()
         t = getNs() / 1000000000.0 * 10.0 * self.speed + self.timeOffs
-
+        f7 = self.getBrightness()
+        gl.glColor3f(f7, f7, f7)
         size = 0.05833333
         yy = -abs(math.sin(t * 0.6662)) * 5.0 - 23.0
         gl.glTranslatef(self.xo + (self.x - self.xo) * a, self.yo + (self.y - self.yo) * a, self.zo + (self.z - self.zo) * a)
@@ -64,7 +65,6 @@ class Zombie(Entity):
         gl.glTranslatef(0.0, yy, 0.0)
         c = 57.29578
         gl.glRotatef(self.rot * c + 180.0, 0.0, 1.0, 0.0)
-
-        self.zombieModel.render(t)
+        self.__zombieModel.render(t, 0.0, 0.0)
         gl.glPopMatrix()
         gl.glDisable(gl.GL_TEXTURE_2D)
