@@ -5,8 +5,8 @@ from pyglet import gl
 class Font:
 
     def __init__(self, name, textures):
-        self.charWidths = [0] * 256
-        self.fontTexture = textures.loadTexture(name, gl.GL_NEAREST)
+        self.__charWidths = [0] * 256
+        self.__fontTexture = textures.loadTexture(name, gl.GL_NEAREST)
         texture = Resources.textures[name]
         w = texture[0]
         h = texture[1]
@@ -20,18 +20,18 @@ class Font:
             for x in range(8):
                 if emptyColumn:
                     break
-                xPixel = xt * 8 + x
+                xPixel = (xt << 3) + x
                 emptyColumn = True
                 for y in range(8):
                     if not emptyColumn:
                         break
-                    yPixel = (yt * 8 + y) * w
-                    pixel = rawPixels[xPixel + yPixel] & 0xFF
+                    yPixel = ((yt << 3) + y) * w
+                    pixel = rawPixels[xPixel + yPixel] & 255
                     if pixel > 128:
                         emptyColumn = False
             if i == 32:
                 x = 4
-            self.charWidths[i] = x
+            self.__charWidths[i] = x
 
     def drawShadow(self, string, x, y, color):
         self.draw(string, x + 1, y + 1, color, True)
@@ -41,35 +41,38 @@ class Font:
         if darken:
             color = (color & 0xFCFCFC) >> 2
         gl.glEnable(gl.GL_TEXTURE_2D)
-        gl.glBindTexture(gl.GL_TEXTURE_2D, self.fontTexture)
+        gl.glBindTexture(gl.GL_TEXTURE_2D, self.__fontTexture)
         t = tesselator
-        t.init()
+        t.begin()
         t.color(color)
         xo = 0
-        for i in range(len(string)):
-            char = string[i]
-            if char == '&':
+        i = 0
+        while i < len(string):
+            if string[i] == '&':
                 cc = '0123456789abcdef'.index(string[i + 1])
-                br = (cc & 0x8) * 8
-                b = (cc & 0x1) * 191 + br
-                g = ((cc & 0x2) >> 1) * 191 + br
-                r = ((cc & 0x4) >> 2) * 191 + br
+                br = (cc & 8) << 3
+                b = (cc & 1) * 191 + br
+                g = ((cc & 2) >> 1) * 191 + br
+                r = ((cc & 4) >> 2) * 191 + br
                 color = r << 16 | g << 8 | b
                 i += 2
                 if darken:
                     color = (color & 0xFCFCFC) >> 2
+
                 t.color(color)
 
-            ix = ord(char) % ord('\020') * 8
-            iy = ord(char) // ord('\020') * 8
-            t.vertexUV(x + xo, y + 8, 0.0, ix / 128.0, (iy + 8) / 128.0)
-            t.vertexUV(x + xo + 8, y + 8, 0.0, (ix + 8) / 128.0, (iy + 8) / 128.0)
-            t.vertexUV(x + xo + 8, y, 0.0, (ix + 8) / 128.0, iy / 128.0)
+            ix = ord(string[i]) % ord('\020') << 3
+            iy = ord(string[i]) // ord('\020') << 3
+            f13 = 7.99
+            t.vertexUV(x + xo, y + f13, 0.0, ix / 128.0, (iy + f13) / 128.0)
+            t.vertexUV(x + xo + f13, y + f13, 0.0, (ix + f13) / 128.0, (iy + f13) / 128.0)
+            t.vertexUV(x + xo + f13, y, 0.0, (ix + f13) / 128.0, iy / 128.0)
             t.vertexUV(x + xo, y, 0.0, ix / 128.0, iy / 128.0)
 
-            xo += self.charWidths[ord(char)]
+            xo += self.__charWidths[ord(string[i])]
+            i += 1
 
-        t.flush()
+        t.end()
         gl.glDisable(gl.GL_TEXTURE_2D)
 
     def width(self, string):
